package TelnetAccess;

use lib qw( /usr/sausalito/perl );
use Sauce::Service;

$TelnetAccess::Lockdir          = "/var/lock";
$TelnetAccess::Inetd_conf       = "/etc/inetd.conf";
$TelnetAccess::Inetd_pid        = "/var/run/inetd.pid";
$TelnetAccess::SecretTelnetPort = "telnet";
$TelnetAccess::ShellSymlink     = "/bin/usersh";
$TelnetAccess::GoodShell        = "/bin/bash";
$TelnetAccess::BadShell         = "/bin/badsh";

#
# changeAccess (code)
# returns a message string describing what happened.
#
sub changeAccess
{
  my $code = shift;

  my %accessTable =
  (
    none => [0, 0],
    root => [1, 0],
    reg  => [1, 1]
  );
  return "" if (!defined($accessTable{$code}));
  return set_telnet_server_on($accessTable{$code}[0]) . "\n" .
         set_telnet_server_open($accessTable{$code}[1]) . "\n";
}

#
# set_telnet_server_on
#
# Arguments: 1 for on, 0 for off
# Return value: a status string
# Side effects: modifies inetd.conf
#
sub set_telnet_server_on
{
	my $state = shift;
	
	my $enabled = $state ? 'on' : 'off';

	service_set_inetd('telnet', $enabled);
	service_send_signal('inetd', 'HUP');
	
	return "Telnet server " . $state?"started":"stopped";
}

#
# get_telnet_server_on
#
# Is the telnet server set to be on?
# Returns 1 if the telnet server is activated, 0 if deactivated
# Arguments: none
# Side effects: none
#
sub get_telnet_server_on
{
  open(INETD,$Inetd_conf) || return "Cannot read $Inetd_conf: $!";
  while (<INETD>)
  {
    if (/^$SecretTelnetPort\s/o)
    {
      close INETD;
      return 1;
    }
  }
  close INETD;
  return 0;
}

#
# set_telnet_server_open
#
# Set whether only root can telnet in, or anyone at all
# Arguments: 1 for anyone, 0 for root only
#
sub set_telnet_server_open
{
  my $newState = shift;

  unlink($ShellSymlink);
  symlink($newState?$GoodShell:$BadShell, $ShellSymlink) ||
      return "Error creating shell symlink, go in and fix manually";
}

#
# get_telnet_server_open
#
# Check whether telnet access is open
# return 0 if only root can log in, 1 if any user can, -1 if the symlink
# doesn't exist!
#
sub get_telnet_server_open
{
  my $whichShell = readlink($ShellSymlink);
  return 1 if ($whichShell eq $GoodShell);
  return 0 if ($whichShell eq $BadShell);
  return -1;
}

1;
